@@ -4,13 +4,12 @@ where
     F: FnMut(&[T]) -> Result<(), String>,
 {
     let size = sequence.len();
-    all_permutations_internal(sequence, size, size, on_permutation)
+    all_permutations_internal(sequence, size, on_permutation)
 }
 
 fn all_permutations_internal<F, T>(
     sequence: &mut [T],
     size: usize,
-    n: usize,
     on_permutation: &mut F,
 ) -> Result<(), String>
 where
@@ -21,7 +20,7 @@ where
     }
 
     for i in 0..size {
-        all_permutations_internal(sequence, size - 1, n, on_permutation)?;
+        all_permutations_internal(sequence, size - 1, on_permutation)?;
 
         if size % 2 == 1 {
             // If size is odd, swap first and last element.
